/*****************************************************************************************************************
Written by Artur Araujo
April-June 2016
Modified by Artur Araujo
December 2017

artur.stat@gmail.com

while working for the
Luxembourg Institute of Health
on the IDEAL project

http://www.ideal.rwth-aachen.de/
*****************************************************************************************************************/

* Log current folder ;
%xlog(cd);

* Determine path to script ;
%let ScriptDir=%sysfunc(
	tranwrd(
		%sysget(SAS_EXECFILEPATH),
		%sysget(SAS_EXECFILENAME),
	)
);

* Set current folder ;
x cd "&ScriptDir";

* Log current folder ;
%xlog(cd);

* Define local libraries ;
libname NORMAL "..\library\normal";

* Define file reference ;
filename nof1 DISK '..\data\N of 1 example.csv';

/*****************************************************************************************************************
Programs for
Araujo, Artur, 2018, Statistical Analysis of Series of N-of-1 Trials Using SAS

Chapter 4: Importing and handling data using data steps
*****************************************************************************************************************/

/*****************************************************************************************************************
Program 4.1: Importing data from an external file using a data step
*****************************************************************************************************************/

data NORMAL.ndata;
	infile nof1 dsd dlm="," firstobs=2;
	input Patient Treatment $ Cycle $ Pair $ Y;
	drop Pair;
run;

/*****************************************************************************************************************
Program 4.2: Sorting the data
*****************************************************************************************************************/

proc sort data=NORMAL.ndata;
	by Patient Cycle;
run;

/*****************************************************************************************************************
Program 4.3: Adding period information to the data using a data step
*****************************************************************************************************************/

* Add the Period variable to NORMAL.ndata ;
data NORMAL.ndata;
	set NORMAL.ndata;
	by Patient;
	if first.Patient then Period=1;
	else Period+1;
	charPeriod=put(Period, 8. -L);
	drop Period;
	rename charPeriod=Period;
run;

* Reorder variables in NORMAL.ndata ;
data NORMAL.ndata;
	retain Patient Treatment Cycle Period Y;
	set NORMAL.ndata;
run;

* Make sure NORMAL.ndata is sorted
by increasing order of Patient and Period;
proc sort data=NORMAL.ndata;
	by Patient Period;
run;

/*****************************************************************************************************************
Program 4.4: Creating unbalanced data using a data step
*****************************************************************************************************************/

data NORMAL.ndata_unbalanced;
	set NORMAL.ndata;
	if (Patient=11 & Cycle=3) then delete;
	if (Patient=12 & Cycle^=1) then delete;
run;

/*****************************************************************************************************************
Program 4.5: Creating a dataset of outcome differences using a data step
*****************************************************************************************************************/

data NORMAL.ddata;
	merge
		NORMAL.ndata(drop=Period where=(Treatment="A") rename=(Y=YA) )
		NORMAL.ndata(drop=Period where=(Treatment="B") rename=(Y=YB) );
	by Patient Cycle;
	drop Treatment;
	dY=YB-YA;
run;

/*****************************************************************************************************************
Program 4.6: Creating an unbalanced dataset of outcome differences using a data step
*****************************************************************************************************************/

data NORMAL.ddata_unbalanced;
	merge
		NORMAL.ndata_unbalanced(drop=Period where=(Treatment="A") rename=(Y=YA) )
		NORMAL.ndata_unbalanced(drop=Period where=(Treatment="B") rename=(Y=YB) );
	by Patient Cycle;
	drop Treatment;
	dY=YB-YA;
run;
