/*****************************************************************************************************************
Written by Artur Araujo
April-June 2016

artur.stat@gmail.com

while working for the
Luxembourg Institute of Health
on the IDEAL project

http://www.ideal.rwth-aachen.de/
*****************************************************************************************************************/

* Log current folder ;
%xlog(cd);

* Determine path to script ;
%let ScriptDir=%sysfunc(
	tranwrd(
		%sysget(SAS_EXECFILEPATH),
		%sysget(SAS_EXECFILENAME),
	)
);

* Set current folder ;
x cd "&ScriptDir";

* Log current folder ;
%xlog(cd);

* Define local libraries ;
libname NORMAL "..\library\normal";

/*****************************************************************************************************************
Programs for
Araujo, Artur, 2018, Statistical Analysis of Series of N-of-1 Trials Using SAS

Chapter 8: The paired t-test
*****************************************************************************************************************/

/*****************************************************************************************************************
Program 8.1: Performing a two-sided paired t-test with 5% significance level
*****************************************************************************************************************/

title "Two-sided paired t-test 5% significance level";
proc ttest
		data=NORMAL.ddata
		alpha=0.05
		dist=normal
		h0=0
		sides=2
		test=diff
		ci=none
		plots=none;
	paired YB*YA;
run;

/*****************************************************************************************************************
Program 8.2: Performing an alternative two-sided paired t-test with 5% significance level
*****************************************************************************************************************/

title "Alternative two-sided paired t-test 5% significance level";
proc ttest
		data=NORMAL.ddata
		alpha=0.05
		dist=normal
		h0=0
		sides=2
		ci=none
		plots=none;
	var dY;
run;

/*****************************************************************************************************************
Program 8.3: Performing a two-sided per patient paired t-test with 5% significance level
*****************************************************************************************************************/

title "Two-sided per patient paired t-test 5% significance level";
proc ttest
		data=NORMAL.ddata
		alpha=0.05
		dist=normal
		h0=0
		sides=2
		test=diff
		ci=none
		plots=none;
	paired YB*YA;
	by Patient;
run;

/*****************************************************************************************************************
Program 8.4: Performing an alternative two-sided per patient paired t-test with 5% significance level
*****************************************************************************************************************/

title "Alternative two-sided per patient paired t-test 5% significance level";
proc ttest
		data=NORMAL.ddata
		alpha=0.05
		dist=normal
		h0=0
		sides=2
		ci=none
		plots=none;
	var dY;
	by Patient;
run;

title; * clear all titles ;
